﻿[CmdletBinding()]
Param(
  [Parameter(Mandatory=$True)]
   [string]$Name,
   [Parameter(Mandatory=$True)]
   [string]$Path,
   [Parameter(Mandatory=$True)]
   [string]$FileName,
   [string]$Version,
   [string]$ServiceName,
   [switch]$Is64bit=$True
)

# Site configuration
$SiteCode = "PS1" 
$ProviderMachineName = "cm01.viamonstra.local" 

# Import the ConfigurationManager module 
if((Get-Module ConfigurationManager) -eq $null) {
    Import-Module "$($ENV:SMS_ADMIN_UI_PATH)\..\ConfigurationManager.psd1"
}

# Connect to the site's drive if it is not already present
if((Get-PSDrive -Name $SiteCode -PSProvider CMSite -ErrorAction SilentlyContinue) -eq $null) {
    New-PSDrive -Name $SiteCode -PSProvider CMSite -Root $ProviderMachineName 
}

# Save current location
$SaveLocation = Get-Location

# Set the current location to be the site code.
Set-Location "$($SiteCode):\"

# Check Arguments
#$Name = "Snow"
#$Path = "%programfiles%\LicenseManager"
#$FileName = "client64.exe"
#$Version = "3.7.0.25994"
#$ServiceName = "SnowInventoryClient"

# Generate CI Name
$CheckName = "Installation"
if ($Version) {
    $CheckName += " and Version"
    if ($ServiceName) {
        $CheckName = "Installation, Version and Service State"
    }
} else {
    if ($ServiceName) {
        $CheckName = "Installation and Service State"
    }
}
$CheckName += " Check"
$CIName = "CT $Name - $CheckName"

# Remove Existing CI if any
Get-CMBaseline -Name $CIName | Remove-CMBaseline -Force
Get-CMConfigurationItem -Name $CIName -Fast | Remove-CMConfigurationItem -Force

# Create new CI
$ci = New-CMConfigurationItem -Name $CIName -CreationType WindowsOS

# Create File Setting
$temp = $ci | Add-CMComplianceSettingFile -path $Path -FileName $FileName -NoRule -SettingName "Exe file" -Is64Bit:$Is64bit
$setting = $ci | Get-CMComplianceSetting -SettingName "Exe File"

# Create File Existance Rule
$rule = $setting | New-CMComplianceRuleExistential -RuleName "Exe File Must Exist" -Existence MustExist
$temp = $ci | Add-CMComplianceSettingRule -Rule $rule

if ($Version) {
    # Create File Version Rule
    $rule = $setting | New-CMComplianceRuleVersion -RuleName "Exe File Version" -ExpressionOperator IsEquals -ExpectedValue $Version
    $temp = $ci | Add-CMComplianceSettingRule -Rule $rule
}

if ($ServiceName) {
    # Create PS Script to check service state
    $ServiceStatusScript = @"
    `$ServiceName = '$ServiceName'
    (Get-Service -Name `$ServiceName -ErrorAction SilentlyContinue | Select -ExpandProperty Status) -eq "Running"
"@

    #Create Script Setting
    $temp = $ci | Add-CMComplianceSettingScript -DataType Boolean -DiscoveryScriptText $ServiceStatusScript -DiscoveryScriptLanguage PowerShell -SettingName "Service State" -NoRule
    $setting = $ci | Get-CMComplianceSetting -SettingName "Service State"

    # Create Service State rule
    $rule = $setting | New-CMComplianceRuleValue -RuleName "Service is Running" -ExpressionOperator IsEquals -ExpectedValue "True"
    $temp = $ci | Add-CMComplianceSettingRule -Rule $rule
}

# Create Baseline
$baseline = New-CMBaseline -Name $CIName 
$temp = Set-CMBaseline -Name $CIName -AddOSConfigurationItem $ci.CI_ID

#Create Deployment of Baseline
#...

Set-Location $SaveLocation